@@ -19,21 +19,22 @@ from enum import Enum
 from pm4py.util import constants, exec_utils
 from pm4py.util import variants_util
 
-from typing import Optional, Dict, Any, Union, Tuple, List
-from pm4py.objects.log.obj import EventLog, EventStream
+from typing import Optional, Dict, Any, Union
+from pm4py.objects.org.sna.obj import SNA
 import pandas as pd
 
 
 class Parameters(Enum):
     ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
     RESOURCE_KEY = constants.PARAMETER_CONSTANT_RESOURCE_KEY
+    CASE_ID_KEY = constants.PARAMETER_CONSTANT_CASEID_KEY
     BETA = "beta"
 
 
 BETA = Parameters.BETA
 
 
-def apply(log: pd.DataFrame, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> List[Any]:
+def apply(log: pd.DataFrame, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> SNA:
     """
     Calculates the HW metric
 
@@ -59,11 +60,13 @@ def apply(log: pd.DataFrame, parameters: Optional[Dict[Union[str, Parameters], A
 
     resource_key = exec_utils.get_param_value(Parameters.RESOURCE_KEY, parameters, xes.DEFAULT_RESOURCE_KEY)
     beta = exec_utils.get_param_value(Parameters.BETA, parameters, 0)
+    case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, constants.CASE_CONCEPT_NAME)
 
     parameters_variants = {case_statistics.Parameters.ACTIVITY_KEY: resource_key,
-                           case_statistics.Parameters.ATTRIBUTE_KEY: resource_key}
+                           case_statistics.Parameters.ATTRIBUTE_KEY: resource_key,
+                           case_statistics.Parameters.CASE_ID_KEY: case_id_key}
 
-    variants_occ = {x["variant"]: x["case:concept:name"] for x in
+    variants_occ = {x["variant"]: x[case_id_key] for x in
                     case_statistics.get_variant_statistics(log, parameters=parameters_variants)}
     variants_resources = list(variants_occ.keys())
     resources = [variants_util.get_activities_from_variant(y) for y in variants_resources]
@@ -97,4 +100,10 @@ def apply(log: pd.DataFrame, parameters: Optional[Dict[Union[str, Parameters], A
         for key2 in sum_i_to_j[key1]:
             metric_matrix[key1][key2] = sum_i_to_j[key1][key2] / dividend
 
-    return [metric_matrix, flat_list, True]
+    connections = {}
+    for key1 in sum_i_to_j:
+        for key2 in sum_i_to_j[key1]:
+            connections[(flat_list[key1], flat_list[key2])] = sum_i_to_j[key1][key2] / dividend
+            metric_matrix[key1][key2] = sum_i_to_j[key1][key2] / dividend
+
+    return SNA(connections, True)
