@@ -14,4 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.reduction import reducer, variants
+from pm4py.algo.reduction import process_tree
+
+import warnings
+
+warnings.warn("The reduction package will be removed in a future release.")
