@@ -14,8 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-
-from pm4py.algo.simulation import montecarlo, playout
+from pm4py.algo.simulation import playout
 
 import pkgutil
 if pkgutil.find_loader("tree_generator"):
