@@ -14,32 +14,29 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
+__doc__ = """
+"""
+
 import warnings
 from typing import Callable, Any, Union
 
 from pm4py.objects.log import obj as log_inst
 import pandas as pd
 from pm4py.objects.log.obj import EventLog, EventStream
+from pm4py.utils import __event_log_deprecation_warning
+import deprecation
 
 
+@deprecation.deprecated("2.3.0", "3.0.0", details="the EventLog class will be removed in a future release.")
 def filter_log(f: Callable[[Any], bool], log: log_inst.EventLog) -> Union[log_inst.EventLog, log_inst.EventStream]:
     """
     Filters the log according to a given (lambda) function.
 
-    Parameters
-    ----------
-    f
-        function that specifies the filter criterion, may be a lambda
-    log
-        event log; either EventLog or EventStream Object
-
-    Returns
-    -------
-    log
-        filtered event log if object provided is correct; original log if not correct
-
+    :param f: function that specifies the filter criterion, may be a lambda
+    :param log: event log; either EventLog or EventStream Object
+    :rtype: ``Union[log_inst.EventLog, log_inst.EventStream]``
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+    __event_log_deprecation_warning(log)
 
     if isinstance(log, log_inst.EventLog):
         return log_inst.EventLog(list(filter(f, log)), attributes=log.attributes, classifiers=log.classifiers,
@@ -56,42 +53,29 @@ def filter_trace(f: Callable[[Any], bool], trace: log_inst.Trace) -> log_inst.Tr
     """
     Filters the trace according to a given (lambda) function.
 
-    Parameters
-    ----------
-    f
-        function that specifies the filter criterion, may be a lambda
-    trace
-        trace; PM4Py trace object
-
-    Returns
-    -------
-    trace
-        filtered trace if object provided is correct; original log if not correct
+    :param f: function that specifies the filter criterion, may be a lambda
+    :param trace: trace; PM4Py trace object
+    :rtype: ``log_inst.Trace``
     """
+    __event_log_deprecation_warning(trace)
+
     if isinstance(trace, log_inst.Trace):
         return log_inst.Trace(list(filter(f, trace)), attributes=trace.attributes)
     else:
         warnings.warn('input trace object is not of the appropriate type, filter() not applied')
 
 
+@deprecation.deprecated("2.3.0", "3.0.0", details="the EventLog class will be removed in a future release.")
 def sort_log(log: log_inst.EventLog, key, reverse: bool = False) -> Union[log_inst.EventLog, log_inst.EventStream]:
     """
     Sorts the event log according to a given key.
 
-    Parameters
-    ----------
-    log
-        event log object; either EventLog or EventStream
-    key
-        sorting key
-    reverse
-        indicates whether sorting should be reversed or not
-
-    Returns
-    -------
-        sorted event log if object provided is correct; original log if not correct
+    :param log: event log object; either EventLog or EventStream
+    :param key: sorting key
+    :param reverse: indicates whether sorting should be reversed or not
+    :rtype: ``Union[log_inst.EventLog, log_inst.EventStream]``
     """
-    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+    __event_log_deprecation_warning(log)
 
     if isinstance(log, log_inst.EventLog):
         return log_inst.EventLog(sorted(log, key=key, reverse=reverse), attributes=log.attributes,
@@ -105,22 +89,18 @@ def sort_log(log: log_inst.EventLog, key, reverse: bool = False) -> Union[log_in
         return log
 
 
+@deprecation.deprecated("2.3.0", "3.0.0", details="the EventLog class will be removed in a future release.")
 def sort_trace(trace: log_inst.Trace, key, reverse: bool = False) -> log_inst.Trace:
     """
+    Sorts the events in a trace according to a given key.
 
-    Parameters
-    ----------
-    trace
-        input trace
-    key
-        sorting key
-    reverse
-        indicate whether sorting should be reversed (default False)
-
-    Returns
-    -------
-        sorted trace if object provided is correct; original log if not correct
+    :param trace: input trace
+    :param key: sorting key
+    :param reverse: indicates whether sorting should be reversed (default False)
+    :rtype: ``log_inst.Trace``
     """
+    __event_log_deprecation_warning(trace)
+
     if isinstance(trace, log_inst.Trace):
         return log_inst.Trace(sorted(trace, key=key, reverse=reverse))
     else:
