@@ -16,9 +16,9 @@
 '''
 from pm4py.objects.log.util import insert_classifier, log, sampling, \
     sorting, index_attribute, get_class_representation, get_prefixes, \
-    get_log_encoded, interval_lifecycle, log_regex, basic_filter, \
-    filtering_utils, split_train_test, time_from_previous, xes
+    get_log_encoded, interval_lifecycle, basic_filter, \
+    filtering_utils, split_train_test, xes, artificial
 import pkgutil
 
 if pkgutil.find_loader("pandas"):
-    from pm4py.objects.log.util import prefix_matrix, dataframe_utils
+    from pm4py.objects.log.util import dataframe_utils
