@@ -23,38 +23,41 @@ MAX_EDGE_PENWIDTH_GRAPHVIZ = 2.6
 MIN_EDGE_PENWIDTH_GRAPHVIZ = 1.0
 
 
-def human_readable_stat(c):
+def human_readable_stat(timedelta_seconds, stat_locale: dict = {}):
     """
     Transform a timedelta expressed in seconds into a human readable string
 
     Parameters
     ----------
-    c
+    timedelta_seconds
         Timedelta expressed in seconds
+    stat_locale
+        Dict mapping stat strings
 
     Returns
     ----------
     string
         Human readable string
     """
-    c = int(float(c))
-    years = c // 31104000
-    months = c // 2592000
-    days = c // 86400
-    hours = c // 3600 % 24
-    minutes = c // 60 % 60
-    seconds = c % 60
+    timedelta_seconds = int(float(timedelta_seconds))
+    years = timedelta_seconds // 31104000
+    months = timedelta_seconds // 2592000
+    days = timedelta_seconds // 86400
+    hours = timedelta_seconds // 3600 % 24
+    minutes = timedelta_seconds // 60 % 60
+    seconds = timedelta_seconds % 60
+    
     if years > 0:
-        return str(years) + "Y"
+        return str(years) + stat_locale.get("year", "Y")
     if months > 0:
-        return str(months) + "MO"
+        return str(months) + stat_locale.get("month", "MO")
     if days > 0:
-        return str(days) + "D"
+        return str(days) + stat_locale.get("day", "D")
     if hours > 0:
-        return str(hours) + "h"
+        return str(hours) + stat_locale.get("hour", "h")
     if minutes > 0:
-        return str(minutes) + "m"
-    return str(seconds) + "s"
+        return str(minutes) + stat_locale.get("minute", "m")
+    return str(seconds) + stat_locale.get("second", "s")
 
 
 def get_arc_penwidth(arc_measure, min_arc_measure, max_arc_measure):
@@ -185,3 +188,34 @@ def open_opsystem_image_viewer(file_name):
         os.startfile(file_name)
     elif os.name == 'posix':  # For Linux, Mac, etc.
         subprocess.call(('xdg-open', file_name))
+
+
+def get_corr_hex(num):
+    """
+    Gets correspondence between a number
+    and an hexadecimal string
+
+    Parameters
+    -------------
+    num
+        Number
+
+    Returns
+    -------------
+    hex_string
+        Hexadecimal string
+    """
+    if num < 10:
+        return str(int(num))
+    elif num < 11:
+        return "A"
+    elif num < 12:
+        return "B"
+    elif num < 13:
+        return "C"
+    elif num < 14:
+        return "D"
+    elif num < 15:
+        return "E"
+    elif num < 16:
+        return "F"
