@@ -15,15 +15,14 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 import tempfile
-import uuid
 from copy import deepcopy
 from enum import Enum
 
 from graphviz import Graph
 
 from pm4py.objects.process_tree.utils import generic
-from pm4py.util import exec_utils
-from typing import Optional, Dict, Any, Union, Tuple
+from pm4py.util import exec_utils, constants
+from typing import Optional, Dict, Any, Union
 from pm4py.objects.process_tree.obj import ProcessTree
 import graphviz
 
@@ -33,10 +32,11 @@ class Parameters(Enum):
     COLOR_MAP = "color_map"
     ENABLE_DEEPCOPY = "enable_deepcopy"
     FONT_SIZE = "font_size"
+    BGCOLOR = "bgcolor"
 
 
 # maps the operators to the ProM strings
-operators_mapping = {"->": "seq", "X": "xor", "+": "and", "*": "xor loop", "O": "or"}
+operators_mapping = {"->": "seq", "X": "xor", "+": "and", "*": "xor loop", "O": "or", "<>": "interleaving"}
 
 
 def get_color(node, color_map):
@@ -55,48 +55,6 @@ def get_color(node, color_map):
     return "black"
 
 
-def repr_tree(tree, viz, current_node, rec_depth, color_map, parameters):
-    """
-    Represent a subtree on the GraphViz object
-
-    Parameters
-    -----------
-    tree
-        Current subtree
-    viz
-        GraphViz object
-    current_node
-        Father node of the current subtree
-    rec_depth
-        Reached recursion depth
-    color_map
-        Color map
-    parameters
-        Possible parameters of the algorithm.
-
-    Returns
-    -----------
-    gviz
-        (partial) GraphViz object
-    """
-    if tree.operator is None:
-        this_trans_id = str(uuid.uuid4())
-        if tree.label is None:
-            viz.node(this_trans_id, "tau", style='filled', fillcolor='black', shape='point', width="0.075")
-        else:
-            node_color = get_color(tree, color_map)
-            viz.node(this_trans_id, str(tree), color=node_color, fontcolor=node_color)
-        viz.edge(current_node, this_trans_id, dirType='none')
-    else:
-        op_node_identifier = str(uuid.uuid4())
-        node_color = get_color(tree, color_map)
-        viz.node(op_node_identifier, operators_mapping[str(tree.operator)], color=node_color, fontcolor=node_color)
-        viz.edge(current_node, op_node_identifier, dirType='none')
-        viz = repr_tree(tree, viz, op_node_identifier, rec_depth + 1, color_map, parameters)
-
-    return viz
-
-
 def repr_tree_2(tree, viz, color_map, parameters):
     font_size = exec_utils.get_param_value(Parameters.FONT_SIZE, parameters, 15)
     font_size = str(font_size)
@@ -108,7 +66,7 @@ def repr_tree_2(tree, viz, color_map, parameters):
             viz.node(this_node_id, "tau", style='filled', fillcolor='black', shape='point', width="0.075", fontsize=font_size)
         else:
             node_color = get_color(tree, color_map)
-            viz.node(this_node_id, str(tree), color=node_color, fontcolor=node_color, fontsize=font_size)
+            viz.node(this_node_id, str(tree.label), color=node_color, fontcolor=node_color, fontsize=font_size)
     else:
         node_color = get_color(tree, color_map)
         viz.node(this_node_id, operators_mapping[str(tree.operator)], color=node_color, fontcolor=node_color, fontsize=font_size)
@@ -140,7 +98,10 @@ def apply(tree: ProcessTree, parameters: Optional[Dict[Union[str, Parameters], A
         parameters = {}
 
     filename = tempfile.NamedTemporaryFile(suffix='.gv')
-    viz = Graph("pt", filename=filename.name, engine='dot', graph_attr={'bgcolor': 'transparent'})
+
+    bgcolor = exec_utils.get_param_value(Parameters.BGCOLOR, parameters, constants.DEFAULT_BGCOLOR)
+
+    viz = Graph("pt", filename=filename.name, engine='dot', graph_attr={'bgcolor': bgcolor})
     viz.attr('node', shape='ellipse', fixedsize='false')
 
     image_format = exec_utils.get_param_value(Parameters.FORMAT, parameters, "png")
